==> estateplat-common-1.2.3-20180428.030647-70-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtMjcycl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    面积差异处理历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht_mjcycl")
public class FcjyXjspfBaMmhtMjcycl {
    @Id
    private String cllsid;//主键
    private String htlsid;//合同历史表id
    private String clid;//面积差异处理表主键
    private String htid;//合同ID
    private String clfs;//处理方式
    private Double tnjzmjjflx;//按套内建筑面积给付利息(百分之)
    private String sfzxyd;//双方自行约定
    private String zxydnr;//自行约定内容
    private Double jzmjjflx;//建筑面积给付利息(百分之)
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getCllsid() {
        return cllsid;
    }

    public void setCllsid(String cllsid) {
        this.cllsid = cllsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getClid() {
        return clid;
    }

    public void setClid(String clid) {
        this.clid = clid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getClfs() {
        return clfs;
    }

    public void setClfs(String clfs) {
        this.clfs = clfs;
    }

    public Double getTnjzmjjflx() {
        return tnjzmjjflx;
    }

    public void setTnjzmjjflx(Double tnjzmjjflx) {
        this.tnjzmjjflx = tnjzmjjflx;
    }

    public String getSfzxyd() {
        return sfzxyd;
    }

    public void setSfzxyd(String sfzxyd) {
        this.sfzxyd = sfzxyd;
    }

    public String getZxydnr() {
        return zxydnr;
    }

    public void setZxydnr(String zxydnr) {
        this.zxydnr = zxydnr;
    }

    public Double getJzmjjflx() {
        return jzmjjflx;
    }

    public void setJzmjjflx(Double jzmjjflx) {
        this.jzmjjflx = jzmjjflx;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180606.062015-109-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtMjcycl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    面积差异处理历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht_mjcycl")
public class FcjyXjspfBaMmhtMjcycl implements Serializable {
    @Id
    private String cllsid;//主键
    private String htlsid;//合同历史表id
    private String clid;//面积差异处理表主键
    private String htid;//合同ID
    private String clfs;//处理方式
    private Double tnjzmjjflx;//按套内建筑面积给付利息(百分之)
    private String sfzxyd;//双方自行约定
    private String zxydnr;//自行约定内容
    private Double jzmjjflx;//建筑面积给付利息(百分之)
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getCllsid() {
        return cllsid;
    }

    public void setCllsid(String cllsid) {
        this.cllsid = cllsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getClid() {
        return clid;
    }

    public void setClid(String clid) {
        this.clid = clid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getClfs() {
        return clfs;
    }

    public void setClfs(String clfs) {
        this.clfs = clfs;
    }

    public Double getTnjzmjjflx() {
        return tnjzmjjflx;
    }

    public void setTnjzmjjflx(Double tnjzmjjflx) {
        this.tnjzmjjflx = tnjzmjjflx;
    }

    public String getSfzxyd() {
        return sfzxyd;
    }

    public void setSfzxyd(String sfzxyd) {
        this.sfzxyd = sfzxyd;
    }

    public String getZxydnr() {
        return zxydnr;
    }

    public void setZxydnr(String zxydnr) {
        this.zxydnr = zxydnr;
    }

    public Double getJzmjjflx() {
        return jzmjjflx;
    }

    public void setJzmjjflx(Double jzmjjflx) {
        this.jzmjjflx = jzmjjflx;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
